@@ -1,6 +1,6 @@
 package Map::Tube::London;
 
-$Map::Tube::London::VERSION   = '0.76';
+$Map::Tube::London::VERSION   = '0.77';
 $Map::Tube::London::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::London - Interface to the London Tube Map.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =cut
 
@@ -128,15 +128,15 @@ base64 encoded string of the entire map.
     print $IMAGE decode_base64($tube->as_image);
     close($IMAGE);
 
-The L<London Tube Map|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/London-Tube.png>
+The L<London Tube Map|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/London-Tube.png>
 as generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/London-Tube.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/London-Tube.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/London-Tube.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/London-Tube.png"
      alt    = "London Tube Map"
-     width  = "540px"
+     width  = "740px"
      height = "780px"/>
 </a>
 
@@ -148,7 +148,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/manwar/Map-Tube-London>
 
 =head1 BUGS
 
