@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Bakerloo;
 
-$Map::Tube::London::Line::Bakerloo::VERSION   = '0.76';
+$Map::Tube::London::Line::Bakerloo::VERSION   = '0.77';
 $Map::Tube::London::Line::Bakerloo::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Bakerloo - London Tube Map: Bakerloo Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =head1 DESCRIPTION
 
@@ -52,21 +52,26 @@ London Tube Map: Bakerloo Line.
 
 =over 2
 
-=item * The station "Oxford Circus" is also part of L<Central Line|Map::Tube::London::Line::Central>
+=item * The station "Oxford Circus" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
         | L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
-=item * The station "Paddington" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+=item * The station "Paddington" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
 
-=item * The station "Embankment" is also part of L<District Line|Map::Tube::London::Line::District>
+=item * The station "Embankment" is also part of
+          L<District Line|Map::Tube::London::Line::District>
         | L<Northern Line|Map::Tube::London::Line::Northern>.
 
-=item * The station "Baker Street" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+=item * The station "Baker Street" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
-=item * The station "Waterloo" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>
+=item * The station "Waterloo" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Waterloo & City Line|Map::Tube::London::Line::WaterlooCity>.
 
@@ -74,13 +79,13 @@ London Tube Map: Bakerloo Line.
 
 =head1 MAP
 
-London Tube Map: L<Bakerloo Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Bakerloo.png>
+London Tube Map: L<Bakerloo Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Bakerloo.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Bakerloo.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Bakerloo.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Bakerloo.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Bakerloo.png"
      alt    = "London Tube Map: Bakerloo Line"
      width  = "500px"
      height = "500px"/>
@@ -94,7 +99,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/manwar/Map-Tube-London>
 
 =head1 BUGS
 
