@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Central;
 
-$Map::Tube::London::Line::Central::VERSION   = '0.76';
+$Map::Tube::London::Line::Central::VERSION   = '0.77';
 $Map::Tube::London::Line::Central::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Central - London Tube Map: Central Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =head1 DESCRIPTION
 
@@ -76,22 +76,28 @@ London Tube Map: Central Line.
 
 =over 2
 
-=item * The station "Bank" is also part of L<Waterloo & City Line|Map::Tube::London::Line::WaterlooCity>
+=item * The station "Bank" is also part of
+          L<Waterloo & City Line|Map::Tube::London::Line::WaterlooCity>
         | L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
 
-=item * The station "Oxford Circus" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+=item * The station "Oxford Circus" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
-=item * The station "Mile End" is also part of L<District Line|Map::Tube::London::Line::District>.
+=item * The station "Mile End" is also part of
+          L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Notting Hill Gate" is also part of L<District Line|Map::Tube::London::Line::District>.
+=item * The station "Notting Hill Gate" is also part of
+          L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Liverpool Street" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+=item * The station "Liverpool Street" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
-=item * The station "Stratford" is also part of L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>
+=item * The station "Stratford" is also part of
+          L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<London Overground Line|Map::Tube::London::Line::Overground>
 
@@ -99,13 +105,13 @@ London Tube Map: Central Line.
 
 =head1 MAP
 
-London Tube Map: L<Central Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png>
+London Tube Map: L<Central Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Central.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Central.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Central.png"
      alt    = "London Tube Map: Central Line"
      width  = "500px"
      height = "500px"/>
@@ -119,7 +125,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/manwar/Map-Tube-London>
 
 =head1 BUGS
 
