@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Circle;
 
-$Map::Tube::London::Line::Circle::VERSION   = '0.76';
+$Map::Tube::London::Line::Circle::VERSION   = '0.77';
 $Map::Tube::London::Line::Circle::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Circle - London Tube Map: Circle Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =head1 DESCRIPTION
 
@@ -62,35 +62,44 @@ London Tube Map: Circle Line.
 
 =over 2
 
-=item * The station "Edgware Road" is also part of L<District Line|Map::Tube::London::Line::District>
+=item * The station "Edgware Road" is also part of
+          L<District Line|Map::Tube::London::Line::District>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
 
-=item * The station "Hammersmith" is also part of L<District Line|Map::Tube::London::Line::District>
+=item * The station "Hammersmith" is also part of
+          L<District Line|Map::Tube::London::Line::District>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Picadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "High Street Kensington" is also part of L<District Line|Map::Tube::London::Line::District>.
+=item * The station "High Street Kensington" is also part of
+          L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Gloucester Road" is also part of L<District Line|Map::Tube::London::Line::District>.
+=item * The station "Gloucester Road" is also part of
+          L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Paddington" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+=item * The station "Paddington" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Moorgate" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "Moorgate" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
         | L<Northern Line|Map::Tube::London::Line::Northern>.
 
-=item * The station "King's Cross St Pancras" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "King's Cross St Pancras" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
         | L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Picadilly Line|Map::Tube::London::Line::Piccadilly>
         | L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
-=item * The station "Liverpool Street" is also part of L<Central Line|Map::Tube::London::Line::Central>
+=item * The station "Liverpool Street" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
-=item * The station "Baker Street" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "Baker Street" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
@@ -99,13 +108,13 @@ London Tube Map: Circle Line.
 
 =head1 MAP
 
-London Tube Map: L<Circle Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Circle.png>
+London Tube Map: L<Circle Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Circle.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Circle.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Circle.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Circle.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Circle.png"
      alt    = "London Tube Map: Circle Line"
      width  = "300px"
      height = "600px"/>
