@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::DLR;
 
-$Map::Tube::London::Line::DLR::VERSION   = '0.76';
+$Map::Tube::London::Line::DLR::VERSION   = '0.77';
 $Map::Tube::London::Line::DLR::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::DLR - London Tube Map: Dockland Light Railway Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =head1 DESCRIPTION
 
@@ -76,23 +76,30 @@ London Tube Map: Dockland Light Railway Line.
 
 =over 2
 
-=item * The station "Bank" is also part of L<Central Line|Map::Tube::London::Line::Central>
+=item * The station "Bank" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
         | L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Waterloo & City Line|Map::Tube::London::Line::WaterlooCity>.
 
-=item * The station "Canning Town" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
+=item * The station "Canning Town" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
 
-=item * The station "Canary Wharf" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
+=item * The station "Canary Wharf" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
 
-=item * The station "Monument" is also part of L<District Line|Map::Tube::London::Line::District>.
+=item * The station "Monument" is also part of
+          L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Stratford" is also part of L<Central Line|Map::Tube::London::Line::Central>
+=item * The station "Stratford" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<London Overground Line|Map::Tube::London::Line::Overground>.
 
-=item * The station "Shadwell" is also part of L<London Overground Line|Map::Tube::London::Line::Overground>.
+=item * The station "Shadwell" is also part of
+          L<London Overground Line|Map::Tube::London::Line::Overground>.
 
-=item * The station "West Ham" is also part of L<District Line|Map::Tube::London::Line::District>
+=item * The station "West Ham" is also part of
+          L<District Line|Map::Tube::London::Line::District>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
 
@@ -100,13 +107,13 @@ London Tube Map: Dockland Light Railway Line.
 
 =head1 MAP
 
-London Tube Map: L<Dockland Light Railway Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/DLR.png>
+London Tube Map: L<Dockland Light Railway Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/DLR.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/DLR.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/DLR.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/DLR.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/DLR.png"
      alt    = "London Tube Map: Dockland Light Railway Line"
      width  = "800px"
      height = "800px"/>
@@ -120,7 +127,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/Manwar/map-Tube-London>
 
 =head1 BUGS
 
