@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::District;
 
-$Map::Tube::London::Line::District::VERSION   = '0.76';
+$Map::Tube::London::Line::District::VERSION   = '0.77';
 $Map::Tube::London::Line::District::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::District - London Tube Map: District Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =head1 DESCRIPTION
 
@@ -86,46 +86,63 @@ London Tube Map: District Line.
 
 =over 2
 
-=item * The station "Hammersmith" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+=item * The station "Hammersmith" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Barons Court" is also part of L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
+=item * The station "Barons Court" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Barking" is also part of L<London Overground Line|Map::Tube::London::Line::Overground>.
+=item * The station "Barking" is also part of
+          L<London Overground Line|Map::Tube::London::Line::Overground>.
 
-=item * The station "Earl's Court" is also part of L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
+=item * The station "Earl's Court" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "South Kensington" is also part of L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
+=item * The station "South Kensington" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Victoria" is also part of L<Victoria Line|Map::Tube::London::Line::Victoria>.
+=item * The station "Victoria" is also part of
+          L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
-=item * The station "Whitechapel" is also part of L<London Overground Line|Map::Tube::London::Line::Overground>.
+=item * The station "Whitechapel" is also part of
+          L<London Overground Line|Map::Tube::London::Line::Overground>.
 
-=item * The station "Aldgate East" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
+=item * The station "Aldgate East" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
 
-=item * The station "Paddington" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "Paddington" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>.
 
-=item * The station "Edgware Road" is also part of L<Circle Line|Map::Tube::London::Line::Circle>.
+=item * The station "Edgware Road" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>.
 
-=item * The station "High Street Kensington" is also part of L<Circle Line|Map::Tube::London::Line::Circle>.
+=item * The station "High Street Kensington" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>.
 
-=item * The station "Notting Hill Gate" is also part of L<Central Line|Map::Tube::London::Line::Central>.
+=item * The station "Notting Hill Gate" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>.
 
-=item * The station "Mile End" is also part of L<Central Line|Map::Tube::London::Line::Central>.
+=item * The station "Mile End" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>.
 
-=item * The station "Gloucester Road" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+=item * The station "Gloucester Road" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Embankment" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+=item * The station "Embankment" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<Northern Line|Map::Tube::London::Line::Northern>.
 
-=item * The station "Monument" is also part of L<Central Line|Map::Tube::London::Line::Central>
+=item * The station "Monument" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
         | L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
 
-=item * The station "West Ham" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "West Ham" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
 
@@ -133,13 +150,13 @@ London Tube Map: District Line.
 
 =head1 MAP
 
-London Tube Map: L<District Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/District.png>
+London Tube Map: L<District Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/District.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/District.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/District.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/District.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/District.png"
      alt    = "London Tube Map: District Line"
      width  = "400px"
      height = "600px"/>
@@ -153,7 +170,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/manwar/Map-Tube-London>
 
 =head1 BUGS
 
