@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Jubilee;
 
-$Map::Tube::London::Line::Jubilee::VERSION   = '0.76';
+$Map::Tube::London::Line::Jubilee::VERSION   = '0.77';
 $Map::Tube::London::Line::Jubilee::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Jubilee - London Tube Map: Jubilee Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =head1 DESCRIPTION
 
@@ -54,54 +54,67 @@ London Tube Map: Jubilee Line.
 
 =over 2
 
-=item * The station "Canada Water" is also part of L<London Overground Line|Map::Tube::London::Line::Overground>.
+=item * The station "Canada Water" is also part of
+          L<London Overground Line|Map::Tube::London::Line::Overground>.
 
-=item * The station "Canning Town" is also part of L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
+=item * The station "Canning Town" is also part of
+          L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
 
-=item * The station "Wembley Park" is also part of L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
+=item * The station "Wembley Park" is also part of
+          L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
-=item * The station "Bond Street" is also part of L<Central Line|Map::Tube::London::Line::Central>.
+=item * The station "Bond Street" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>.
 
-=item * The station "Green Park" is also part of L<Victoria Line|Map::Tube::London::Line::Victoria>
+=item * The station "Green Park" is also part of
+          L<Victoria Line|Map::Tube::London::Line::Victoria>
         | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Finchley Road" is also part of L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
+=item * The station "Finchley Road" is also part of
+          L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
-=item * The station "Baker Street" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "Baker Street" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
-=item * The station "Waterloo" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+=item * The station "Waterloo" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Waterloo & City Line|Map::Tube::London::Line::WaterlooCity>.
 
-=item * The station "Stratford" is also part of L<Central Line|Map::Tube::London::Line::Central>
+=item * The station "Stratford" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
         | L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>
         | L<London Overground Line|Map::Tube::London::Line::Overground>.
 
-=item * The station "London Bridge" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
+=item * The station "London Bridge" is also part of
+          L<Northern Line|Map::Tube::London::Line::Northern>.
 
-=item * The station "West Ham" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "West Ham" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<District Line|Map::Tube::London::Line::District>
         | L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
 
-=item * The station "West Hampstead" is also part of L<London Overground Line|Map::Tube::London::Line::Overground>.
+=item * The station "West Hampstead" is also part of
+          L<London Overground Line|Map::Tube::London::Line::Overground>.
 
-=item * The station "Westminster" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+=item * The station "Westminster" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
         | L<District Line|Map::Tube::London::Line::District>.
 
 =back
 
 =head1 MAP
 
-London Tube Map: L<Jubilee Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Jubilee.png>
+London Tube Map: L<Jubilee Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Jubilee.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Jubilee.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Jubilee.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Jubilee.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Jubilee.png"
      alt    = "London Tube Map: Jubilee Line"
      width  = "600px"
      height = "400px"/>
@@ -115,7 +128,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/manwar/Map-Tube-London>
 
 =head1 BUGS
 
