@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Metropolitan;
 
-$Map::Tube::London::Line::Metropolitan::VERSION   = '0.76';
+$Map::Tube::London::Line::Metropolitan::VERSION   = '0.77';
 $Map::Tube::London::Line::Metropolitan::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Metropolitan - London Tube Map: Metropolitan Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =head1 DESCRIPTION
 
@@ -61,22 +61,28 @@ London Tube Map: Metropolitan Line.
 
 =over 2
 
-=item * The station "Aldgate" is also part of L<Circle Line|Map::Tube::London::Line::Circle>.
+=item * The station "Aldgate" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>.
 
-=item * The station "Liverpool Street" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "Liverpool Street" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Central Line|Map::Tube::London::Line::Central>.
 
-=item * The station "Wembley Park" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
+=item * The station "Wembley Park" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
 
-=item * The station "Finchley Road" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
+=item * The station "Finchley Road" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
 
-=item * The station "Baker Street" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "Baker Street" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
 
-=item * The station "King's Cross St. Pancras" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+=item * The station "King's Cross St. Pancras" is also part of
+          L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Victoria Line|Map::Tube::London::Line::Victoria>
         | L<Northern Line|Map::Tube::London::Line::Northern>
@@ -86,13 +92,13 @@ London Tube Map: Metropolitan Line.
 
 =head1 MAP
 
-London Tube Map: L<Metropoiltan Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Metropolitan.png>
+London Tube Map: L<Metropoiltan Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Metropolitan.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Metropolitan.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Metropolitan.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Metropolitan.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Metropolitan.png"
      alt    = "LondonM Tube Map: Metropolitan Line"
      width  = "500px"
      height = "500px"/>
@@ -106,7 +112,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/manwar/Map-Tube-London>
 
 =head1 BUGS
 
