@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Northern;
 
-$Map::Tube::London::Line::Northern::VERSION   = '0.76';
+$Map::Tube::London::Line::Northern::VERSION   = '0.77';
 $Map::Tube::London::Line::Northern::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Northern - London Tube Map: Northern Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =head1 DESCRIPTION
 
@@ -107,43 +107,53 @@ London Tube Map: Northern Line.
 
 =over 2
 
-=item * The station "Bank" is also part of L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>
+=item * The station "Bank" is also part of
+          L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>
         | L<Waterloo & City Line|Map::Tube::London::Line::WaterlooCity>.
 
-=item * The station "Warren Street" is also part of L<Victoria Line|Map::Tube::London::Line::Victoria>.
+=item * The station "Warren Street" is also part of
+          L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
-=item * The station "Tottenham Court Road" is also part of L<Central Line|Map::Tube::London::Line::Central>.
+=item * The station "Tottenham Court Road" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>.
 
-=item * The station "Leicester Square" is also part of L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
+=item * The station "Leicester Square" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Euston" is also part of L<Victoria Line|Map::Tube::London::Line::Victoria>
+=item * The station "Euston" is also part of
+          L<Victoria Line|Map::Tube::London::Line::Victoria>
         | L<London Overground Line|Map::Tube::London::Line::Overground>.
 
-=item * The station "London Bridge" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
+=item * The station "London Bridge" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
 
-=item * The station "Embankment" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+=item * The station "Embankment" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<Circle Line|Map::Tube::London::Line::Circle>
         | L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Waterloo" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+=item * The station "Waterloo" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<Waterloo & City Line|Map::Tube::London::Line::WaterlooCity>.
 
-=item * The station "Elephant & Castle" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>.
+=item * The station "Elephant & Castle" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>.
 
-=item * The station "Stockwell" is also part of L<Victoria Line|Map::Tube::London::Line::Victoria>.
+=item * The station "Stockwell" is also part of
+          L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
 =back
 
 =head1 MAP
 
-London Tube Map: L<Northern Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Northern.png>
+London Tube Map: L<Northern Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Northern.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Northern.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Northern.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Northern.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Northern.png"
      alt    = "London Tube Metro: Northern Line"
      width  = "400px"
      height = "600px"/>
@@ -157,7 +167,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/manwar/Map-Tube-London>
 
 =head1 BUGS
 
