@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Overground;
 
-$Map::Tube::London::Line::Central::VERSION   = '0.76';
+$Map::Tube::London::Line::Central::VERSION   = '0.77';
 $Map::Tube::London::Line::Central::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Overground - London Tube Map: London Overground Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =encoding utf8
 
@@ -117,54 +117,70 @@ London Tube Map: London Overground Line.
 
 =over 2
 
-=item * The station "Barking" is also part of L<District Line|Map::Tube::London::Line::District>
+=item * The station "Barking" is also part of
+          L<District Line|Map::Tube::London::Line::District>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
 
-=item * The station "Blackhorse Road" is also part of L<Victoria Line|Map::Tube::London::Line::Victoria>.
+=item * The station "Blackhorse Road" is also part of
+          L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
-=item * The station "Willesden Junction" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>.
+=item * The station "Willesden Junction" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>.
 
-=item * The station "Queen's Park" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>.
+=item * The station "Queen's Park" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>.
 
-=item * The station "Euston" is also part of L<Northern Line|Map::Tube::London::Line::Northern>
+=item * The station "Euston" is also part of
+          L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
-=item * The station "Shepherd's Bush" is also part of L<Central Line|Map::Tube::London::Line::Central>.
+=item * The station "Shepherd's Bush" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>.
 
-=item * The station "Kensington (Olympia)" is also part of L<District Line|Map::Tube::London::Line::District>.
+=item * The station "Kensington (Olympia)" is also part of
+          L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "West Brompton" is also part of L<District Line|Map::Tube::London::Line::District>.
+=item * The station "West Brompton" is also part of
+          L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Gunnersbury" is also part of L<District Line|Map::Tube::London::Line::District>.
+=item * The station "Gunnersbury" is also part of
+          L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Clapham High Street" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
+=item * The station "Clapham High Street" is also part of
+          L<Northern Line|Map::Tube::London::Line::Northern>.
 
-=item * The station "Canada Water" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
+=item * The station "Canada Water" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
 
-=item * The station "Shadwell" is also part of L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
+=item * The station "Shadwell" is also part of
+          L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
 
-=item * The station "Whitechapel" is also part of L<District Line|Map::Tube::London::Line::District>
+=item * The station "Whitechapel" is also part of
+          L<District Line|Map::Tube::London::Line::District>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
 
-=item * The station "Highbury & Islington" is also part of L<Victoria Line|Map::Tube::London::Line::Victoria>.
+=item * The station "Highbury & Islington" is also part of
+          L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
-=item * The station "Stratford" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>
+=item * The station "Stratford" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<Central Line|Map::Tube::London::Line::Central>
         | L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
 
-=item * The station "West Hampstead" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
+=item * The station "West Hampstead" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
 
 =back
 
 =head1 MAP
 
-London Tube Map: L<London Overground Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Overground.png>
+London Tube Map: L<London Overground Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Overground.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Overground.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Overground.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Overground.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Overground.png"
      alt    = "London Tube Map: London Overground Line"
      width  = "500px"
      height = "700px"/>
@@ -178,7 +194,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/manwar/Map-Tube-London>
 
 =head1 BUGS
 
