@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Victoria;
 
-$Map::Tube::London::Line::Victoria::VERSION   = '0.76';
+$Map::Tube::London::Line::Victoria::VERSION   = '0.77';
 $Map::Tube::London::Line::Victoria::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Victoria - London Tube Map: Victoria Line.
 
 =head1 VERSION
 
-Version 0.76
+Version 0.77
 
 =head1 DESCRIPTION
 
@@ -43,46 +43,57 @@ London Tube Map: Victoria Line.
 
 =over 2
 
-=item * The station "Finsbury Park" is also part of L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
+=item * The station "Finsbury Park" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Euston" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
+=item * The station "Euston" is also part of
+          L<Northern Line|Map::Tube::London::Line::Northern>.
 
-=item * The station "King's Cross St. Pancras" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+=item * The station "King's Cross St. Pancras" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
         | L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Finsbury Park" is also part of L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
+=item * The station "Finsbury Park" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Blackhorse Road" is also part of L<London Overground Line|Map::Tube::London::Line::Overground>.
+=item * The station "Blackhorse Road" is also part of
+          L<London Overground Line|Map::Tube::London::Line::Overground>.
 
-=item * The station "Warren Street" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
+=item * The station "Warren Street" is also part of
+          L<Northern Line|Map::Tube::London::Line::Northern>.
 
-=item * The station "Oxford Circus" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+=item * The station "Oxford Circus" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<Central Line|Map::Tube::London::Line::Central>.
 
-=item * The station "Green Park" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>
+=item * The station "Green Park" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
 
-=item * The station "Victoria" is also part of L<District Line|Map::Tube::London::Line::District>
+=item * The station "Victoria" is also part of
+          L<District Line|Map::Tube::London::Line::District>
         | L<Circle Line|Map::Tube::London::Line::Circle>.
 
-=item * The station "Stockwell" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
+=item * The station "Stockwell" is also part of
+          L<Northern Line|Map::Tube::London::Line::Northern>.
 
-=item * The station "Highbury & Islington" is also part of L<London Overground Line|Map::Tube::London::Line::Overground>.
+=item * The station "Highbury & Islington" is also part of
+          L<London Overground Line|Map::Tube::London::Line::Overground>.
 
 =back
 
 =head1 MAP
 
-London Tube Map: L<Victoria Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Victoria.png>
+London Tube Map: L<Victoria Line|https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Victoria.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Victoria.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Victoria.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Victoria.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-London/master/maps/Victoria.png"
      alt    = "London Tube Map: Victoria Line"
      width  = "500px"
      height = "500px"/>
@@ -96,7 +107,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-London>
+L<https://github.com/manwar/Map-Tube-London>
 
 =head1 BUGS
 
